@@ -12,7 +12,8 @@ class CleanLogger:
         self, 
         name, 
         streamhandler_level = logging.INFO,
-        formatter = logging.Formatter('%(asctime)s -- %(levelname)8s -- %(name)s -- %(message)s', datefmt="%Y-%m-%dT%H:%M:%S%z")
+        formatter = logging.Formatter('%(asctime)s -- %(levelname)8s -- %(name)s -- %(message)s', datefmt="%Y-%m-%dT%H:%M:%S%z"),
+        max_history = 100,
     ):
         self._name = self.__create_clean_name(name)
         log = logging.getLogger(self._name)
@@ -32,6 +33,9 @@ class CleanLogger:
             COUNTER_STREAM : {}
         }
 
+        self._history = []
+        self._max_history = max_history
+
     def log(self):
         return self._log
 
@@ -39,27 +43,31 @@ class CleanLogger:
         return self._name
 
     def log_message(self, level, message):
+        self.__count(level)
+        self._history.append((
+            datetime.datetime.now().isoformat(),
+            level,
+            self._name,
+            message,
+        ))
+        if len(self._history) > self._max_history:
+            self._history = self._history[max(0, len(self._history) - self._max_history):]
         self._log.log(level, message)
 
     def debug(self, msg):
-        self.__count(logging.DEBUG)
-        self._log.debug(msg)
+        self.log_message(logging.DEBUG, msg)
 
     def info(self, msg):
-        self.__count(logging.INFO)
-        self._log.info(msg)
+        self.log_message(logging.INFO, msg)
 
     def warning(self, msg):
-        self.__count(logging.WARNING)
-        self._log.warning(msg)
+        self.log_message(logging.WARNING, msg)
 
     def error(self, msg):
-        self.__count(logging.ERROR)
-        self._log.error(msg)
+        self.log_message(logging.ERROR, msg)
 
     def critical(self, msg):
-        self.__count(logging.CRITICAL)
-        self._log.critical(msg)
+        self.log_message(logging.CRITICAL, msg)
 
     def exception(self, msg):
         self.__count(logging.ERROR)
@@ -125,6 +133,14 @@ class CleanLogger:
         now = now.replace(":", "").replace(".", "")
         return now
         
+    def get_message_history(self, max_num = 10, level_filter = None):
+        filtered_history = [
+            (ts, level, name, msg)
+            for (ts, level, name, msg) in self._history
+            if level_filter == None or level_filter == level
+        ]
+        return filtered_history[max(0, len(filtered_history) - max_num):]
+
     def __count(self, loglevel):
         for counter in self._counters.values():
             if not loglevel in counter.keys():
